# NOWAuthExecutor

NOWAuthExecutor performs the token check for authorization. It stores the owner ID belonging
    to the authorised user and also the `user_id` of the allowed users with access to the flow
    deployed by the user.
